EthSignature class

Ethereum Signature structure

Constructors

EthSignature({required Uint8List requestId, required Uint8List signature})

Properties

hashCode int
The hash code for this object.
no setterinherited
requestId Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() Map<int, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCbor(Map<int, dynamic> cbor) EthSignature