QRAnimationController class

QR code animation controller with additional features

Constructors

QRAnimationController(AnimatedQR _animatedQR)

Properties

currentIndex int
Get the current part index
no setter
currentPart String
Get the current part
no setter
hashCode int
The hash code for this object.
no setterinherited
isPaused bool
Check if animation is paused
no setter
isPlaying bool
Check if animation is currently playing
no setter
partCount int
Get the total number of parts
no setter
progress double
Get progress as percentage (0.0 to 1.0)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

jumpTo(int index) → void
Jump to specific part
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pause the animation
play() Stream<String>
Start or resume the animation
stepBackward() → void
Manually step to previous part
stepForward() → void
Manually step to next part
stop() → void
Stop the animation completely
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited