BCURDecoder class
BC-UR decoder for parsing UR-formatted QR codes
Constructors
Properties
- expectedFragmentCount → int?
-
Get expected fragment count
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
Check if decoding is complete
no setter
- progress → double
-
Get decoding progress (0.0 to 1.0)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- solvedFragmentCount → int
-
Get solved fragment count
no setter
Methods
-
getResult(
) → Uint8List? - Get the decoded result (only available when complete)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
receivePart(
String ur) → bool - Process a UR part for multi-part decoding Returns true if this part was useful
-
reset(
) → void - Reset decoder state
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decodeEthSignature(
String ur) → EthSignature? - Decode an Ethereum signature
-
decodeEthSignRequest(
String ur) → EthSignRequest? - Decode an Ethereum sign request
-
decodeSingle(
String ur) → BCURPart - Decode a single UR string